@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2010-2015 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2010-2016 Mir Calculate. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -25,9 +25,10 @@ from calculate.lib.datavars import (Variable, VariableError, ReadonlyVariable,
 from calculate.lib.utils.common import getValueFromConfig
 from calculate.lib.variables import user
 from calculate.lib.utils.files import (readLinesFile, process,
-                                       listDirectory)
+                                       listDirectory, readFile)
 from calculate.desktop._cl_keys import getKey
 from itertools import *
+import glob
 from calculate.lib.cl_template import templateFunction
 from calculate.lib.cl_ini_parser import iniParser
 import hashlib
@@ -202,6 +203,23 @@ class VariableClDesktopXfceMixer(ReadonlyVariable):
                 self.Get('cl_desktop_gst_data').get('channels', [])))
 
 
+class VariableClDesktopXfcePointers(ReadonlyVariable):
+    """
+    Список устройств-указателей для xfce
+    """
+    type = "list"
+
+    def get(self):
+        def generate():
+            for name_fn in sorted(
+                    glob.glob("/sys/class/input/mouse*/device/name")):
+                data = readFile(name_fn)
+                if data:
+                    yield data.strip().replace(" ", "_").replace("/","")
+
+        return list(generate())
+
+
 class VariableClDesktopOnlineData(ReadonlyTableVariable, DomainInfoHelper):
     """
     Information about online users
